==> modelestimator_v2-0.0.1.tar.gz: modelestimator_v2-0.0.1/tests/test_case_3.py <==
import tempfile
import numpy as np
import os
import sys
sys.path.insert(1, os.path.join(sys.path[0], '..'))
from modelestimator._bw_estimator.bw_estimator import bw_estimator
from modelestimator._handle_input.handle_input_file import handle_input_file

def test_case_2(tmpdir):
        #   Create directory paths
    CURRENT_DIR = os.path.dirname(__file__)
    TEST_FILES_PATH = os.path.join(CURRENT_DIR, 'test_case_3\\')

    #   Create sequence file path
    FILE_PATH_1 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_1.fa")
    FILE_PATH_2 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_2.fa")
    FILE_PATH_3 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_3.fa")

    #   Load reference Q and EQ
    REFERENCE_Q_PATH = os.path.join(TEST_FILES_PATH, 'test_case_3_Q.txt')
    REFERENCE_Q = np.loadtxt(REFERENCE_Q_PATH)
    REFERENCE_EQ_PATH = os.path.join(TEST_FILES_PATH, 'test_case_3_EQ.txt')
    REFERENCE_EQ = np.loadtxt(REFERENCE_EQ_PATH)

    #   Calculate Q and EQ
    FILE_PATH_LIST = [FILE_PATH_1, FILE_PATH_2, FILE_PATH_3]
    # THRESHOLD = 0.001
    # CALCULATED_Q, CALCULATED_EQ = modelestimator.modelestimator(FILE_PATH_LIST, THRESHOLD)

    FORMAT = "fasta"
    MULTIALIGNMENT_LIST = []
    for FILE in FILE_PATH_LIST:
        MULTIALIGNMENT = handle_input_file(FILE, FORMAT)
        MULTIALIGNMENT_LIST.append(MULTIALIGNMENT)
    THRESHOLD = 0.001
    CALCULATED_Q, CALCULATED_EQ = bw_estimator(FORMAT, THRESHOLD, MULTIALIGNMENT_LIST)

    #   Assert that calculated and references are close. Expected to pass
    assert(np.allclose(CALCULATED_Q, REFERENCE_Q))
    assert(np.allclose(CALCULATED_EQ, REFERENCE_EQ))

==> modelestimator-v2-0.0.4.tar.gz: modelestimator-v2-0.0.4/tests/test_case_3.py <==
import tempfile
import numpy as np
import os
import sys
sys.path.insert(1, os.path.join(sys.path[0], '..'))
from modelestimator._bw_estimator.bw_estimator import bw_estimator
from modelestimator._handle_input.handle_input_file import handle_input_file

def test_case_2(tmpdir):
        #   Create directory paths
    CURRENT_DIR = os.path.dirname(__file__)
    TEST_FILES_PATH = os.path.join(CURRENT_DIR, 'test_case_3\\')

    #   Create sequence file path
    FILE_PATH_1 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_1.fa")
    FILE_PATH_2 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_2.fa")
    FILE_PATH_3 = os.path.join(TEST_FILES_PATH, "JTT_balancedtree_32sequences_10000long_3.fa")

    #   Load reference Q and EQ
    REFERENCE_Q_PATH = os.path.join(TEST_FILES_PATH, 'test_case_3_Q.txt')
    REFERENCE_Q = np.loadtxt(REFERENCE_Q_PATH)
    REFERENCE_EQ_PATH = os.path.join(TEST_FILES_PATH, 'test_case_3_EQ.txt')
    REFERENCE_EQ = np.loadtxt(REFERENCE_EQ_PATH)

    #   Calculate Q and EQ
    FILE_PATH_LIST = [FILE_PATH_1, FILE_PATH_2, FILE_PATH_3]
    FORMAT = "fasta"
    MULTIALIGNMENT_LIST = []
    for FILE in FILE_PATH_LIST:
        MULTIALIGNMENT = handle_input_file(FILE, FORMAT)
        MULTIALIGNMENT_LIST.append(MULTIALIGNMENT)
    THRESHOLD = 0.001
    CALCULATED_Q, CALCULATED_EQ = bw_estimator(THRESHOLD, MULTIALIGNMENT_LIST)

    #   Assert that calculated and references are close. Expected to pass
    assert(np.allclose(CALCULATED_Q, REFERENCE_Q))
    assert(np.allclose(CALCULATED_EQ, REFERENCE_EQ))
